@@ -89,14 +89,36 @@
 #' # tempdir()
 #' }
 #'
-#' @references {
+#' @references 
 #' Araya-Salas, M., & Smith-Vidaurre, G. (2017). warbleR: An R package to streamline analysis of animal acoustic signals. Methods in Ecology and Evolution, 8(2), 184-191.
-#' }
+#'
 #' @author Marcelo Araya-Salas (\email{marcelo.araya@@ucr.ac.cr})
-# last modification on mar-13-2018 (MAS)
 
-full_spectrograms <- function(X = NULL, flim = NULL, sxrow = 5, rows = 10, collevels = seq(-40, 0, 1), ovlp = 50, parallel = 1,
-                              wl = 512, gr = FALSE, pal = reverse.gray.colors.2, cex = 1, it = "jpeg", flist = NULL, overwrite = TRUE, path = NULL, pb = TRUE, fast.spec = FALSE, labels = "selec", horizontal = FALSE, song = NULL, suffix = NULL, dest.path = NULL, only.annotated = FALSE, ...) {
+full_spectrograms <- function(X = NULL,
+                              flim = NULL,
+                              sxrow = 5,
+                              rows = 10,
+                              collevels = seq(-40, 0, 1),
+                              ovlp = 50,
+                              parallel = 1,
+                              wl = 512,
+                              gr = FALSE,
+                              pal = reverse.gray.colors.2,
+                              cex = 1,
+                              it = "jpeg",
+                              flist = NULL,
+                              overwrite = TRUE,
+                              path = NULL,
+                              pb = TRUE,
+                              fast.spec = FALSE,
+                              labels = "selec",
+                              horizontal = FALSE,
+                              song = NULL,
+                              suffix = NULL,
+                              dest.path = NULL,
+                              only.annotated = FALSE,
+                              ...
+) {
   #### set arguments from options
   # get function arguments
   argms <- methods::formalArgs(full_spectrograms)
@@ -143,12 +165,15 @@ full_spectrograms <- function(X = NULL, flim = NULL, sxrow = 5, rows = 10, colle
 
 
   # stop if files are not in working directory
-  if (length(files) == 0) stop("no sound files in working directory")
+  if (length(files) == 0) stop("no sound files in 'path' supplied")
 
   # subet based on file list provided (flist)
   if (!is.null(flist)) files <- files[files %in% flist]
   if (length(files) == 0) stop("selected sound files are not in working directory")
 
+  # subset based on sound files in X
+  if (!is.null(X)) files <- files[files %in% X$sound.files]
+  
   # set W to null by default (this is the detection data.frame)
   W <- NULL
 
